<?php

/*
Plugin Name: Effortless Marketing
Plugin URI: http://wordpress.org/plugins/effortless-marketing
Description: Effortless Marketing is a holistic marketing solution for store owners from feed creation and
 submission to smart campaign creation. Easily reach shoppers on Google, Facebook & more
Version: 1.4.1
Author: Adcore
Author URI: https://www.adcore.com/
License: GPLv2 or later
*/



if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/**
 * Generated by the WordPress Option Page generator
 * at http://jeremyhixon.com/wp-tools/option-page/
 */

class EffortlessMarketing {
	private $effortless_marketing_setting_options;
	private const DEFAULT_DOMAIN_SERVER = "https://tools.adcore.com";
	public function __construct() {
		add_action( 'admin_menu', array( $this, 'effortless_marketing_setting_add_plugin_page' ) );
		add_action( 'admin_init', array( $this, 'effortless_marketing_setting_page_init' ) );
		add_action( 'admin_enqueue_scripts', array( $this,'enqueue_angular' ) );
		add_action( 'admin_print_scripts', array( $this, 'admin_inline_js' ) );
		register_activation_hook( __FILE__, array( $this, 'effortless_marketing_activate' ) );
		register_deactivation_hook( __FILE__, array( $this, 'effortless_marketing_deactivate' ));
	}

	public function effortless_marketing_setting_add_plugin_page() {
		global $em_page;
		$em_page = add_menu_page( 'Effortless Marketing Page', 'Effortless Marketing', 'manage_options', 'effortless-marketing', array($this, 'include_woo_app' ));
		
		if ( $_SERVER["SERVER_NAME"] == 'localhost' ){		
			add_submenu_page(
			'effortless-marketing',
			'Effortless Marketing Setting', // page_title
			'Effortless Marketing Setting', // menu_title
			'manage_options', // capability
			'effortless_marketing_setting', // menu_slug
			array( $this, 'effortless_marketing_setting_create_admin_page' ) // function
		);

		}

	}

	private function get_params(){
		$nonce = wp_create_nonce();
		$current_user = wp_get_current_user();
		$title = get_bloginfo( 'name' );
		$site_domain = get_site_url(); //  http://localhost
		$site_url = $_SERVER['HTTP_HOST']; //  localhost
		$params = array(
			"user_email" => get_bloginfo('admin_email'),
			"shop_url" => $site_url,
			"domain" => $site_domain,
			"shop_name" => $title,
			"user_name" => $current_user->user_login,
		);
		$instance = base64_encode(json_encode($params));
		return $instance;
	}

	public function include_woo_app(){
		$active_plugins = apply_filters( 'active_plugins', get_option( 'active_plugins' ) );
		if ( in_array( 'woocommerce/woocommerce.php', $active_plugins ) ) {

			$instance = $this->get_params();
			$effortless_marketing_setting_options = get_option( 'effortless_marketing_setting_option_name' ); // Array of All Options
			$server_domain = empty($effortless_marketing_setting_options['server_domain']) ? self::DEFAULT_DOMAIN_SERVER : $effortless_marketing_setting_options['server_domain'];
			$url = $server_domain . "/api/woo/check?instance_id=" . $instance;
			$response = wp_remote_post( $url, $args );
			if ( is_wp_error( $response ) ) {
				$error_message = $response->get_error_message();
				echo "Something went wrong: $error_message";
			 } else {
				if ( $response['body'] == 'True' ) {
					echo "<app-root></app-root>";

				} else if ( $response['body'] == 'Deactivated' ) {
					echo "<div> Current shop has a credential in server, but it is deactivated. Please deactivate this plugin and then activate it again. Thank you. </div>";
				} else {
					$endpoint  = '/wc-auth/v1/authorize';
					$params = array(
						'app_name'     => 'Effortless Marketing',
						'scope'        => 'read',
						'user_id'      => $instance,
						'return_url'   => get_site_url() . '/wp-admin/admin.php?page=effortless-marketing',
						'callback_url' => $server_domain . '/api/woo/callback'
					);
		
					$url = get_site_url() . $endpoint . '?' . http_build_query( $params );
					echo $url;
					wp_redirect( $url );
					exit;
				}
			 }
		} else {
			echo '<div> <p> Effortless marketing plugin works based on WooCommerce Pluign, but it is not installed or activated in your site. </p>
			<p> Please try again after you install WooCommerce Plugin. Thank you. </p></div>';
		}
	}

	public function enqueue_angular( $hook ) {
		global $em_page;
		if ( $em_page != $hook ) {
        	return;
    	}
		wp_enqueue_style( 'adcore-style', plugin_dir_url( __FILE__ ) . 'css/main.css' ); 
		$scripts = array(
			'runtime.js',
			'polyfills.js',
			'vendor.js',
			'main.js'
		);
		foreach ($scripts as $script) {
			wp_enqueue_script( 'angular' . $script, plugin_dir_url( __FILE__ )  . 'includes/' . $script, array(), '', true ); 
		}
		wp_enqueue_style( 'angular-style', plugin_dir_url( __FILE__ ) . 'includes/styles.css' ); 
	}

	public function admin_inline_js(){ 
		$instance = $this->get_params();
		echo "<script>window.instanceId = '$instance';</script>";
	 } 

	public function effortless_marketing_deactivate() {
		$instance = $this->get_params();
		$effortless_marketing_setting_options = get_option( 'effortless_marketing_setting_option_name' ); // Array of All Options
		$server_domain = empty($effortless_marketing_setting_options['server_domain']) ? self::DEFAULT_DOMAIN_SERVER : $effortless_marketing_setting_options['server_domain'];
		$url = $server_domain . "/api/woo/deactivate?instance_id=" . $instance;
		$response = wp_remote_post( $url, $args );
	}

	public function effortless_marketing_activate() {
		if (is_plugin_active( 'effortless-marketing-woo/effortless-marketing.php' ) ) {
            wp_die( 'Effortless Marketing plugin is already activated. It might be installed from the WooCommerce Market.', NULL, $args = array( 'back_link' => true, ) );
		}
		$instance = $this->get_params();
		$effortless_marketing_setting_options = get_option( 'effortless_marketing_setting_option_name' ); // Array of All Options
		$server_domain = empty($effortless_marketing_setting_options['server_domain']) ? self::DEFAULT_DOMAIN_SERVER : $effortless_marketing_setting_options['server_domain'];
		$url = $server_domain . "/api/woo/activate?instance_id=" . $instance;
		$response = wp_remote_post( $url, $args );
	}

	public function woocommerce_missing_notice() {
		echo '<div class="error"><p> Effortless Marketing depends on WooCommerce to work! Please try again after you install and activate WooCommerce Plugin.</p></div>';
	}

	public function effortless_marketing_setting_create_admin_page() {
		$this->effortless_marketing_setting_options = get_option( 'effortless_marketing_setting_option_name' ); ?>
		<div class="wrap">
			<h2>Effortless Marketing Setting</h2>
			<p></p>
			<?php settings_errors(); ?>

			<form method="post" action="options.php">
				<?php
					settings_fields( 'effortless_marketing_setting_option_group' );
					do_settings_sections( 'effortless-marketing-setting-admin' );
					submit_button();
				?>
			</form>
		</div>
	<?php }

	public function effortless_marketing_setting_page_init() {
		register_setting(
			'effortless_marketing_setting_option_group', // option_group
			'effortless_marketing_setting_option_name', // option_name
			array( $this, 'effortless_marketing_setting_sanitize' ) // sanitize_callback
		);

		add_settings_section(
			'effortless_marketing_setting_setting_section', // id
			'Settings', // title
			array( $this, 'effortless_marketing_setting_section_info' ), // callback
			'effortless-marketing-setting-admin' // page
		);

		add_settings_field(
			'server_domain', // id
			'Server Domain', // title
			array( $this, 'server_domain_callback' ), // callback
			'effortless-marketing-setting-admin', // page
			'effortless_marketing_setting_setting_section' // section
		);
	}

	public function effortless_marketing_setting_sanitize($input) {
		$sanitary_values = array();
		if ( isset( $input['server_domain'] ) ) {
			$sanitary_values['server_domain'] = sanitize_text_field( $input['server_domain'] );
		}

		return $sanitary_values;
	}

	public function effortless_marketing_setting_section_info() {
		
	}

	public function server_domain_callback() {
		printf(
			'<input class="regular-text" type="text" name="effortless_marketing_setting_option_name[server_domain]" id="server_domain" value="%s">',
			isset( $this->effortless_marketing_setting_options['server_domain'] ) ? esc_attr( $this->effortless_marketing_setting_options['server_domain']) : self::DEFAULT_DOMAIN_SERVER
		);
	}

}
if ( is_admin() )
	$effortless_marketing_setting = new EffortlessMarketing();
